@@ -114,17 +114,16 @@ def run_app(project=None, default_config_path=None, default_settings=None,
 
     (options, logan_args) = parser.parse_args(args)
 
-    config_path = options.config
+    config_path = os.path.expanduser(options.config)
 
     if not os.path.exists(config_path):
         raise ValueError("Configuration file does not exist. Use '%s init' to initialize the file." % runner_name)
 
     os.environ['DJANGO_SETTINGS_MODULE'] = 'logan_config'
 
-    importer.install('logan_config', config_path, default_settings, allow_extras=allow_extras)
-
-    if initializer is not None:
-        from django.conf import settings
+    def settings_callback(settings):
+        if initializer is None:
+            return
 
         initializer({
             'project': project,
@@ -132,6 +131,8 @@ def run_app(project=None, default_config_path=None, default_settings=None,
             'settings': settings,
         })
 
+    importer.install('logan_config', config_path, default_settings, allow_extras=allow_extras, callback=settings_callback)
+
     management.execute_from_command_line([runner_name, command] + command_args)
 
     sys.exit(0)
